<?php
/**
 * Plugin initialization file
 *
 * @link              https://www.opensource-excellence.com/
 * @since             1.0.0
 * @package           OSE WP Scan
 *
 * @wordpress-plugin
 * Plugin Name:       OSE WP Scan
 * Description:       OSE WP Scan is a free plugin to do the vulnerability scan and security check for your WordPress website. With the one-click scan request, it will send the comprehensive security report to the specified email address. The tool utilizes WPScan project (https://wpscan.org/) and WPScan Vulnerability Database (https://wpvulndb.com/) to scan the whole WordPress site for plugin and theme vulnerabilities.
 * Version:           1.0.6
 * Author:            Open Source Excellence
 * Author URI:        https://www.opensource-excellence.com/
 * License:           GPL-3.0+
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain:       ose-wp-scan
 * Domain Path:       /languages
 */


/*
 * Plugin constants
 */
if(!defined('OSEWPSCAN_PLUGIN_VERSION'))
    define('OSEWPSCAN_PLUGIN_VERSION', '1.1.0');
if(!defined('OSEWPSCAN_URL'))
    define('OSEWPSCAN_URL', plugin_dir_url( __FILE__ ));
if(!defined('OSEWPSCAN_PATH'))
    define('OSEWPSCAN_PATH', plugin_dir_path( __FILE__ ));
if(!defined('OSEWPSCAN_ENDPOINT'))
    define('OSEWPSCAN_ENDPOINT', 'https://www.1o1wp.com/');
if(!defined('OSEWPSCAN_PROTOCOL'))
    define('OSEWPSCAN_PROTOCOL', 'https');

/*
 * Main class
 */
/**
 * Class Osewpscan
 *
 * This class creates the option page and add the web app script
 */
class Osewpscan
{

    /**
     * The security nonce
     *
     * @var string
     */
    private $_nonce = 'osewpscan_admin';

    /**
     * The option name
     *
     * @var string
     */
    private $option_name = 'ose_wpscan_data';

    /**
     * ose-cp constructor.
     *
     * The main plugin actions registered for WordPress
     */
    public function __construct(){
        // Admin page calls
        add_action('admin_menu',                array($this,'addAdminMenu'));
        add_action('wp_ajax_check_wpscan_data', array($this,'checkAccountData'));
        add_action('wp_ajax_store_wpscan_data',array($this,'storeAccountData'));
        add_action('wp_ajax_send_scan_request',  array($this,'sendScanRequest'));
        add_action('admin_enqueue_scripts',     array($this,'addAdminScripts'));
    }
    public function addAdminScripts($hook){
        if (!strpos($hook,'ose-wpscan')) {
            return;
        }
        wp_enqueue_style('ose-wpscan-milligram', OSEWPSCAN_URL. 'assets/css/milligram.css');
        wp_enqueue_style('ose-wpscan-milligram-map', OSEWPSCAN_URL. 'assets/css/milligram.css.map');
        wp_enqueue_style('ose-wpscan-googleapis', 'https://fonts.googleapis.com/css?family=Roboto:300,300italic,700,700italic');
        wp_enqueue_style('ose-wpscan-normalize', OSEWPSCAN_URL. 'assets/css/normalize.css');
        wp_enqueue_style( 'ose-wpscan-admin', OSEWPSCAN_URL. 'assets/css/ose-wpscan-admin.css');


        wp_enqueue_script( 'ose-wpscan-admin', OSEWPSCAN_URL. 'assets/js/ose-wpscan-admin.js' );
        $admin_options = array(
            'ajax_url' => admin_url( 'admin-ajax.php' ),
            '_nonce'   => wp_create_nonce( $this->_nonce ),
        );
        wp_localize_script( 'ose-wpscan-admin', 'ose_wpscan_exchanger', $admin_options);
    }
    public function addAdminMenu(){
        add_menu_page(
            __( 'OSE WP Scan', 'ose-wpscan' ),
            __( 'OSE WP Scan', 'ose-wpscan' ),
            'manage_options',
            'ose-wpscan',
            array($this, 'adminLayout'),
            'dashicons-testimonial'
        );
    }
    public function adminLayout(){
        $data = $this->getData();
        $user =  wp_get_current_user();
        ?>

        <div class="wrap">
            <form id="ose-wpscan-account-form" class="">
                <!--
                <h3>
                    <?php _e('Account setting', 'ose-wpscan'); ?>
                </h3>
                -->
                <div class="container">
                    <fieldset>
                        <div class="row">
                            <div class="column column-50">
                                <h1><?php _e('OSE WP Scan Settings', 'ose-wpscan'); ?></h1>
                                <label for="email"><?php _e( 'Email', 'ose-wpscan' ); ?></label>
                                <input name="ose_wpscan_email"
                                       id="ose_wpscan_email"
                                       class="regular-text"
                                       type="text"
                                       value="<?php echo (isset($data['email'])) ? $data['email'] : $user->user_email; ?>"/>

                                <p class="privacy-policy">We respect your privacy, please checkout our <a href="https://www.opensource-excellence.com/privacy-policy/" target="_blank">Privacy Policy</a></p>

                                <div class="terms">
                                    <input type="checkbox" class="terms-checkbox" name="terms" id="terms" value="1">
                                    <!--<a id="view-terms" href="" class="viewterms" data-toggle="modal" data-target="#termsModal">Terms and Conditions</a>-->
                                    <a id="view-terms" href="https://www.opensource-excellence.com/terms-and-conditions/" class="viewterms" target="_blank">Terms and Conditions</a>
                                </div>
                                <div id="response-message" class="success-message">

                                </div>

                                <button class="button" id="ose-wpscan-account-save" type="submit" disabled="true">
                                    <?php _e( 'Save', 'ose-wpscan' ); ?>
                                </button>

                                <button class="button" id="ose-wpscan-scan-request" type="button" disabled="true">
                                    <?php _e( 'Request a scan', 'ose-wpscan' ); ?>
                                </button>
                            </div>
                            <div class="column column-50">
                                <img class="ose-logos ose-logo" src="<?php echo OSEWPSCAN_URL. "assets/images/oselogo_small.png"; ?>" alt="Open Source Excellence"/>
                                <p class="notes-ftp"><?php _e( 'We do not store your email address, the email address is used for receiving the scanning report of <a href="https://wpvulndb.com/" target="_blank">WPScan</a>, which has over 11632 vulnerability records in their database. Credits to <a href="https://www.wpscan.org" target="_blank">WPScan</a>.', 'ose-wpscan' ); ?> </p>
                            </div>
                        </div>
                    </fieldset>
                </div>
            </form>

        </div>

        <?php
    }
    private function getData(){
        return get_option($this->option_name, array());
    }
    public function checkAccountData(){
        if (wp_verify_nonce($_POST['security'], $this->_nonce) === false)
            die('Invalid Request! Reload your page please.');

        $data = $this->getData();
        $return = array();
        if(!empty($data['email'])){
            $return['success'] = true;
        }else{
            $return['success'] = false;
        }
        print_r(json_encode($return));exit;
    }
    public function storeAccountData(){

        if (wp_verify_nonce($_POST['security'], $this->_nonce ) === false)
            die('Invalid Request! Reload your page please.');

        $data = $this->getData();

        foreach ($_POST as $field=>$value) {

            if (substr($field, 0, 11) !== "ose_wpscan_")
                continue;

            if (empty($value))
                unset($data[$field]);

            // We remove the ose_wpscan_ prefix to clean things up
            $field = substr($field, 11);

            $data[$field] = esc_attr__($value);

        }
        $data = $this->sanitizeData($data);
        update_option($this->option_name, $data);
        echo __('Saved!', 'ose-wpscan');
        die();

    }
    protected function sanitizeData($data){
        $sanitizedData = array();
        foreach ($data as $key => $val){
            if($key == 'email'){
                $sanitizedData[$key] = sanitize_email($val);
            }else{
                $sanitizedData[$key] = sanitize_text_field($val);
            }
        }
        return $sanitizedData;
    }
    public function sendScanRequest(){
        if (wp_verify_nonce($_POST['security'], $this->_nonce) === false)
            die('Invalid Request! Reload your page please.');

        $data = $this->getData();
        $data = $this->sanitizeData($data);
        if(file_exists(dirname( __FILE__ ) . '/api.php')) {
            require_once (dirname( __FILE__ ) . '/api.php');
            $oseWpscantApi = new oseWpscantApi();
            $result = $oseWpscantApi->sendApiScanRequest($data);
            print_r($result);exit;
        }
    }
}

/*
 * Starts our plugin class, easy!
 */
new Osewpscan();